==> percona-xtrabackup-8.0.30-23.tar.gz: percona-xtrabackup-8.0.30-23/storage/ndb/include/portlib/ndb_localtime.h <==
/* Copyright (c) 2013, 2022, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
#ifndef NDB_LOCALTIME_H
#define NDB_LOCALTIME_H

#include <time.h>

/*
 ndb_locatime_r
 Portability fucntion which emulates the localtime_r() function

**/

static inline
struct tm*
ndb_localtime_r(const time_t *timep, struct tm *result)
{
#ifdef _WIN32
  // NOTE! reversed args and different returntype
  if (localtime_s(result, timep) != 0)
  {
    return NULL;
  }
  return result;
#else
  return localtime_r(timep, result);
#endif
}


#endif

==> percona-xtrabackup-8.3.0-1.tar.gz: percona-xtrabackup-8.3.0-1/storage/ndb/include/portlib/ndb_localtime.h <==
/* Copyright (c) 2013, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
#ifndef NDB_LOCALTIME_H
#define NDB_LOCALTIME_H

#include <time.h>

/*
 ndb_locatime_r
 Portability function which emulates the localtime_r() function

**/

static inline struct tm *ndb_localtime_r(const time_t *timep,
                                         struct tm *result) {
#ifdef _WIN32
  // NOTE! reversed args and different return type
  if (localtime_s(result, timep) != 0) {
    return nullptr;
  }
  return result;
#else
  return localtime_r(timep, result);
#endif
}

#endif
